[FFmpeg-cvslog] tiff: Return more meaningful error codes

Himangi Saraogi git at videolan.org
Mon Mar 30 21:03:58 CEST 2015


ffmpeg | branch: master | Himangi Saraogi <himangi774 at gmail.com> | Mon Mar 30 00:45:56 2015 +0530| [6ed38b1f65b424a4fa92042e0069f350b95e0098] | committer: Diego Biurrun

tiff: Return more meaningful error codes

Signed-off-by: Diego Biurrun <diego at biurrun.de>

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=6ed38b1f65b424a4fa92042e0069f350b95e0098
---

 libavcodec/tiffenc.c |   11 ++++++-----
 1 file changed, 6 insertions(+), 5 deletions(-)

diff --git a/libavcodec/tiffenc.c b/libavcodec/tiffenc.c
index 169360f..a020f5f 100644
--- a/libavcodec/tiffenc.c
+++ b/libavcodec/tiffenc.c
@@ -153,7 +153,8 @@ static int add_entry1(TiffEncoderContext *s,
  * @param dst Output buffer
  * @param n Size of input buffer
  * @param compr Compression method
  * @return Number of output bytes. If an output error is encountered, -1 returned
  */
 static int encode_strip(TiffEncoderContext *s, const int8_t *src,
                         uint8_t *dst, int n, int compr)
@@ -166,14 +167,14 @@ static int encode_strip(TiffEncoderContext *s, const int8_t *src,
         unsigned long zlen = s->buf_size - (*s->buf - s->buf_start);
         if (compress(dst, &zlen, src, n) != Z_OK) {
             av_log(s->avctx, AV_LOG_ERROR, "Compressing failed\n");
-            return -1;
+            return AVERROR_UNKNOWN;
         }
         return zlen;
     }
 #endif
     case TIFF_RAW:
         if (check_size(s, n))
-            return -1;
+            return AVERROR(EINVAL);
         memcpy(dst, src, n);
         return n;
     case TIFF_PACKBITS:
@@ -182,7 +183,7 @@ static int encode_strip(TiffEncoderContext *s, const int8_t *src,
     case TIFF_LZW:
         return ff_lzw_encode(s->lzws, src, n);
     default:
-        return -1;
+        return AVERROR(EINVAL);
     }
 }
 
@@ -291,7 +292,7 @@ static int encode_frame(AVCodecContext *avctx, AVPacket *pkt,
     default:
         av_log(s->avctx, AV_LOG_ERROR,
                "This colors format is not supported\n");
-        return -1;
+        return AVERROR(EINVAL);
     }
 
     if (s->compr == TIFF_DEFLATE       ||
@@ -153,7 +153,8 @@ static int add_entry1(TiffEncoderContext *s,
  * @param n Size of input buffer
  * @param compr Compression method
- * @return Number of output bytes. If an output error is encountered, -1 returned
+ * @return Number of output bytes. If an output error is encountered, a negative
+ * value corresponding to an AVERROR error code is returned.
  */
 static int encode_strip(TiffEncoderContext *s, const int8_t *src,



More information about the ffmpeg-cvslog mailing list